# NERCST

[![PyPI](https://img.shields.io/pypi/v/nercst.svg?label=PyPI&style=flat-square)](https://pypi.org/pypi/nercst/)
[![Python](https://img.shields.io/pypi/pyversions/nercst.svg?label=Python&color=yellow&style=flat-square)](https://pypi.org/pypi/nercst/)
[![Test](https://img.shields.io/github/workflow/status/necst-telescope/NERCST/Test?logo=github&label=Test&style=flat-square)](https://github.com/necst-telescope/NERCST/actions)
[![License](https://img.shields.io/badge/license-MIT-blue.svg?label=License&style=flat-square)](https://github.com/necst-telescope/NERCST/blob/main/LICENSE)

Python package template.

## Features

This library provides:

- Data reduction and calibration software for NECST telescopes.

## Installation

```shell
pip install nercst
```

## Usage

This library is using [Semantic Versioning](https://semver.org).
